==> adminer-3.6.1.zip: adminer-3.6.1/adminer/lang/et.inc.php <==
<?php
$translations = array(
	'Login' => 'Logi sisse',
	'Logout successful.' => 'Väljalogimine õnnestus.',
	'Invalid credentials.' => 'Ebakorrektsed andmed.',
	'Server' => 'Server',
	'Username' => 'Kasutajanimi',
	'Password' => 'Parool',
	'Select database' => 'Vali andmebaas',
	'Invalid database.' => 'Tundmatu andmebaas.',
	'Create new database' => 'Loo uus andmebaas',
	'Table has been dropped.' => 'Tabel on edukalt kustutatud.',
	'Table has been altered.' => 'Tabeli andmed on edukalt muudetud.',
	'Table has been created.' => 'Tabel on edukalt loodud.',
	'Alter table' => 'Muuda tabeli struktuuri',
	'Create table' => 'Loo uus tabel',
	'Table name' => 'Tabeli nimi',
	'engine' => 'andmebaasimootor',
	'collation' => 'tähetabel',
	'Column name' => 'Veeru nimi',
	'Type' => 'Tüüp',
	'Length' => 'Pikkus',
	'Auto Increment' => 'Automaatselt suurenev',
	'Options' => 'Valikud',
	'Save' => 'Salvesta',
	'Drop' => 'Kustuta',
	'Database has been dropped.' => 'Andmebaas on edukalt kustutatud.',
	'Database has been created.' => 'Andmebaas on edukalt loodud.',
	'Database has been renamed.' => 'Andmebaas on edukalt ümber nimetatud.',
	'Database has been altered.' => 'Andmebaasi struktuuri uuendamine õnnestus.',
	'Alter database' => 'Muuda andmebaasi',
	'Create database' => 'Loo uus andmebaas',
	'SQL command' => 'SQL-Päring',
	'Dump' => 'Ekspordi',
	'Logout' => 'Logi välja',
	'database' => 'andmebaas',
	'Use' => 'Kasuta',
	'No tables.' => 'Tabeleid ei leitud.',
	'select' => 'kuva',
	'Create new table' => 'Loo uus tabel',
	'Item has been deleted.' => 'Kustutamine õnnestus.',
	'Item has been updated.' => 'Uuendamine õnnestus.',
	'Item%s has been inserted.' => 'Kirje%s on edukalt lisatud.',
	'Edit' => 'Muuda',
	'Insert' => 'Sisesta',
	'Save and insert next' => 'Salvesta ja lisa järgmine',
	'Delete' => 'Kustuta',
	'Database' => 'Andmebaas',
	'Routines' => 'Protseduurid',
	'Indexes have been altered.' => 'Indeksite andmed on edukalt uuendatud.',
	'Indexes' => 'Indeksid',
	'Alter indexes' => 'Muuda indekseid',
	'Add next' => 'Lisa järgmine',
	'Language' => 'Keel',
	'Select' => 'Kuva',
	'New item' => 'Lisa kirje',
	'Search' => 'Otsi',
	'Sort' => 'Sorteeri',
	'descending' => 'kahanevalt',
	'Limit' => 'Piira',
	'No rows.' => 'Sissekanded puuduvad.',
	'Action' => 'Tegevus',
	'edit' => 'muuda',
	'Page' => 'Lehekülg',
	'Query executed OK, %d row(s) affected.' => 'Päring õnnestus, mõjutatatud ridu: %d.',
	'Error in query' => 'Päringus esines viga',
	'Execute' => 'Käivita',
	'Table' => 'Tabel',
	'Foreign keys' => 'Võõrvõtmed (foreign key)',
	'Triggers' => 'Päästikud (trigger)',
	'View' => 'Vaata',
	'Unable to select the table' => 'Tabeli valimine ebaõnnestus',
	'Invalid CSRF token. Send the form again.' => 'Sobimatu CSRF, palun postitage vorm uuesti.',
	'Comment' => 'Kommentaar',
	'Default values' => 'Vaikimisi väärtused',
	'%d byte(s)' => array('%d bait', '%d baiti'),
	'No commands to execute.' => 'Käsk puudub.',
	'Unable to upload a file.' => 'Faili üleslaadimine pole võimalik.',
	'File upload' => 'Faili üleslaadimine',
	'File uploads are disabled.' => 'Failide üleslaadimine on keelatud.',
	'Routine has been called, %d row(s) affected.' => 'Protseduur täideti edukalt, mõjutatud ridu: %d.',
	'Call' => 'Käivita',
	'No extension' => 'Ei leitud laiendust',
	'None of the supported PHP extensions (%s) are available.' => 'Serveris pole ühtegi toetatud PHP laiendustest (%s).',
	'Session support must be enabled.' => 'Sessioonid peavad olema lubatud.',
	'Session expired, please login again.' => 'Sessioon on aegunud, palun logige uuesti sisse.',
	'Text length' => 'Teksti pikkus',
	'Foreign key has been dropped.' => 'Võõrvõti on edukalt kustutatud.',
	'Foreign key has been altered.' => 'Võõrvõtme andmed on edukalt muudetud.',
	'Foreign key has been created.' => 'Võõrvõri on edukalt loodud.',
	'Foreign key' => 'Võõrvõti',
	'Target table' => 'Siht-tabel',
	'Change' => 'Muuda',
	'Source' => 'Allikas',
	'Target' => 'Sihtkoht',
	'Add column' => 'Lisa veerg',
	'Alter' => 'Muuda',
	'Add foreign key' => 'Lisa võõrvõti',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Indeksi tüüp',
	'Column (length)' => 'Veerg (pikkus)',
	'View has been dropped.' => 'Vaade (VIEW) on edukalt kustutatud.',
	'View has been altered.' => 'Vaade (VIEW) on edukalt muudetud.',
	'View has been created.' => 'Vaade (VIEW) on edukalt loodud.',
	'Alter view' => 'Muuda vaadet (VIEW)',
	'Create view' => 'Loo uus vaade (VIEW)',
	'Name' => 'Nimi',
	'Process list' => 'Protsesside nimekiri',
	'%d process(es) have been killed.' => array('Protsess on edukalt peatatud (%d).', 'Valitud protsessid (%d) on edukalt peatatud.'),
	'Kill' => 'Peata',
	'Parameter name' => 'Parameetri nimi',
	'Database schema' => 'Andmebaasi skeem',
	'Create procedure' => 'Loo uus protseduur',
	'Create function' => 'Loo uus funktsioon',
	'Routine has been dropped.' => 'Protseduur on edukalt kustutatud.',
	'Routine has been altered.' => 'Protseduuri andmed on edukalt muudetud.',
	'Routine has been created.' => 'Protseduur on edukalt loodud.',
	'Alter function' => 'Muuda funktsiooni',
	'Alter procedure' => 'Muuda protseduuri',
	'Return type' => 'Tagastustüüp',
	'Add trigger' => 'Lisa päästik (TRIGGER)',
	'Trigger has been dropped.' => 'Päästik on edukalt kustutatud.',
	'Trigger has been altered.' => 'Päästiku andmed on edukalt uuendatud.',
	'Trigger has been created.' => 'Uus päästik on edukalt loodud.',
	'Alter trigger' => 'Muuda päästiku andmeid',
	'Create trigger' => 'Loo uus päästik (TRIGGER)',
	'Time' => 'Aeg',
	'Event' => 'Sündmus',
	'%d row(s)' => '%d rida',
	'Remove' => 'Eemalda',
	'Are you sure?' => 'Kas oled kindel?',
	'Privileges' => 'Õigused',
	'Create user' => 'Loo uus kasutaja',
	'User has been dropped.' => 'Kasutaja on edukalt kustutatud.',
	'User has been altered.' => 'Kasutaja andmed on edukalt muudetud.',
	'User has been created.' => 'Kasutaja on edukalt lisatud.',
	'Hashed' => 'Häshitud (Hashed)',
	'Column' => 'Veerg',
	'Routine' => 'Protseduur',
	'Grant' => 'Anna',
	'Revoke' => 'Eemalda',
	'%s version: %s through PHP extension %s' => '%s versioon: %s, kasutatud PHP moodul: %s',
	'Logged as: %s' => 'Sisse logitud: %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST-andmete maht on liialt suur. Palun vähendage andmeid või suurendage %s php-seadet.',
	'Move up' => 'Liiguta ülespoole',
	'Move down' => 'Liiguta allapoole',
	'Export' => 'Ekspordi',
	'Tables' => 'Tabelid',
	'Data' => 'Andmed',
	'Output' => 'Väljund',
	'open' => 'näita brauseris',
	'save' => 'salvesta failina',
	'Format' => 'Formaat',
	'Functions' => 'Funktsioonid',
	'Aggregation' => 'Liitmine',
	'Event has been dropped.' => 'Sündmus on edukalt kustutatud.',
	'Event has been altered.' => 'Sündmuse andmed on edukalt uuendatud.',
	'Event has been created.' => 'Sündmus on edukalt loodud.',
	'Alter event' => 'Muuda sündmuse andmeid',
	'Create event' => 'Loo uus sündmus (EVENT)',
	'Start' => 'Alusta',
	'End' => 'Lõpeta',
	'Every' => 'Iga',
	'Status' => 'Staatus',
	'On completion preserve' => 'Lõpetamisel jäta sündmus alles',
	'Events' => 'Sündmused (EVENTS)',
	'Schedule' => 'Ajakava',
	'At given time' => 'Antud ajahetkel',
	'Save and continue edit' => 'Salvesta ja jätka muutmist',
	'original' => 'originaal',
	'Tables have been truncated.' => 'Validud tabelid on edukalt tühjendatud.',
	'Tables have been moved.' => 'Valitud tabelid on edukalt liigutatud.',
	'Tables have been dropped.' => 'Valitud tabelid on edukalt kustutatud.',
	'Tables and views' => 'Tabelid ja vaated',
	'Engine' => 'Implementatsioon',
	'Collation' => 'Tähetabel',
	'Data Length' => 'Andmete pikkus',
	'Index Length' => 'Indeksi pikkus',
	'Data Free' => 'Vaba ruumi',
	'Rows' => 'Ridu',
	',' => ',',
	'Analyze' => 'Analüüsi',
	'Optimize' => 'Optimeeri',
	'Check' => 'Kontrolli',
	'Repair' => 'Paranda',
	'Truncate' => 'Tühjenda',
	'Move to other database' => 'Liiguta teise andmebaasi',
	'Move' => 'Liiguta',
	'%d item(s) have been affected.' => 'Mõjutatud kirjeid: %d.',
	'whole result' => 'Täielikud tulemused',
	'Clone' => 'Kloon',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Maksimaalne väljade arv ületatud. Palun suurendage %s ja %s.',
	'Partition by' => 'Partitsiooni',
	'Partitions' => 'Partitsioonid',
	'Partition name' => 'Partitsiooni nimi',
	'Values' => 'Väärtused',
	'%d row(s) have been imported.' => 'Imporditi %d rida.',
	'anywhere' => 'vahet pole',
	'Import' => 'Impordi',
	'Stop on error' => 'Peatuda vea esinemisel',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[yyyy]',
	'History' => 'Ajalugu',
	'Variables' => 'Muutujad',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Lähte- ja sihtveerud peavad eksisteerima ja omama sama andmetüüpi, sihtveergudel peab olema määratud indeks ning viidatud andmed peavad eksisteerima.',
	'Relations' => 'Seosed',
	'Run file' => 'Käivita fail',
	'Clear' => 'Puhasta',
	'Maximum allowed file size is %sB.' => 'Maksimaalne failisuurus %sB.',
	'Numbers' => 'Numbrilised',
	'Date and time' => 'Kuupäev ja kellaaeg',
	'Strings' => 'Tekstid',
	'Binary' => 'Binaar',
	'Lists' => 'Listid',
	'Editor' => 'Redaktor',
	'E-mail' => 'E-post',
	'From' => 'Kellelt',
	'Subject' => 'Pealkiri',
	'Send' => 'Saada',
	'%d e-mail(s) have been sent.' => 'Saadetud kirju: %d.',
	'Webserver file %s' => 'Fail serveris: %s',
	'File does not exist.' => 'Faili ei leitud.',
	'%d in total' => 'Kokku: %d',
	'Permanent login' => 'Jäta mind meelde',
	'Databases have been dropped.' => 'Andmebaasid on edukalt kustutatud.',
	'Search data in tables' => 'Otsi kogu andmebaasist',
	'schema' => 'struktuur',
	'Schema' => 'Struktuur',
	'Alter schema' => 'Muuda struktuuri',
	'Create schema' => 'Loo struktuur',
	'Schema has been dropped.' => 'Struktuur on edukalt kustutatud.',
	'Schema has been created.' => 'Struktuur on edukalt loodud.',
	'Schema has been altered.' => 'Struktuur on edukalt muudetud.',
	'Sequences' => 'Jadad (sequences)',
	'Create sequence' => 'Loo jada',
	'Alter sequence' => 'Muuda jada',
	'Sequence has been dropped.' => 'Jada on edukalt kustutatud.',
	'Sequence has been created.' => 'Jada on edukalt loodud.',
	'Sequence has been altered.' => 'Jada on edukalt muudetud.',
	'User types' => 'Kasutajatüübid',
	'Create type' => 'Loo tüüp',
	'Alter type' => 'Muuda tüüpi',
	'Type has been dropped.' => 'Tüüp on edukalt kustutatud.',
	'Type has been created.' => 'Tüüp on edukalt loodud.',
	'Double click on a value to modify it.' => 'Väärtuse muutmiseks topelt-kliki sellel.',
	'Use edit link to modify this value.' => 'Väärtuse muutmiseks kasuta muutmislinki.',
	'last' => 'viimane',
	'From server' => 'Serverist',
	'System' => 'Andmebaasimootor',
	'Select data' => 'Vaata andmeid',
	'Show structure' => 'Näita struktuuri',
	'empty' => 'tühi',
	'Network' => 'Võrk (network)',
	'Geometry' => 'Geomeetria',
	'File exists.' => 'Fail juba eksisteerib.',
	'Attachments' => 'Manused',
	'%d query(s) executed OK.' => array('%d päring edukalt käivitatud.', '%d päringut edukalt käivitatud.'),
	'Show only errors' => 'Kuva vaid veateateid',
	'Last page' => 'Viimane lehekülg',
	'Refresh' => 'Uuenda',
	'Invalid schema.' => 'Sobimatu skeema.',
	'Please use one of the extensions %s.' => 'Palun kasuta üht laiendustest %s.',
	'now' => 'nüüd',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tabelid on edukalt kopeeritud.',
	'Copy' => 'Kopeeri',
	'Permanent link' => 'Püsilink',
	'Edit all' => 'Muuda kõiki',
	'HH:MM:SS' => 'HH:MM:SS',
);

==> adminer-3.7.0.zip: adminer-3.7.0/adminer/lang/et.inc.php <==
<?php
$translations = array(
	'Login' => 'Logi sisse',
	'Logout successful.' => 'Väljalogimine õnnestus.',
	'Invalid credentials.' => 'Ebakorrektsed andmed.',
	'Server' => 'Server',
	'Username' => 'Kasutajanimi',
	'Password' => 'Parool',
	'Select database' => 'Vali andmebaas',
	'Invalid database.' => 'Tundmatu andmebaas.',
	'Create new database' => 'Loo uus andmebaas',
	'Table has been dropped.' => 'Tabel on edukalt kustutatud.',
	'Table has been altered.' => 'Tabeli andmed on edukalt muudetud.',
	'Table has been created.' => 'Tabel on edukalt loodud.',
	'Alter table' => 'Muuda tabeli struktuuri',
	'Create table' => 'Loo uus tabel',
	'Table name' => 'Tabeli nimi',
	'engine' => 'andmebaasimootor',
	'collation' => 'tähetabel',
	'Column name' => 'Veeru nimi',
	'Type' => 'Tüüp',
	'Length' => 'Pikkus',
	'Auto Increment' => 'Automaatselt suurenev',
	'Options' => 'Valikud',
	'Save' => 'Salvesta',
	'Drop' => 'Kustuta',
	'Database has been dropped.' => 'Andmebaas on edukalt kustutatud.',
	'Database has been created.' => 'Andmebaas on edukalt loodud.',
	'Database has been renamed.' => 'Andmebaas on edukalt ümber nimetatud.',
	'Database has been altered.' => 'Andmebaasi struktuuri uuendamine õnnestus.',
	'Alter database' => 'Muuda andmebaasi',
	'Create database' => 'Loo uus andmebaas',
	'SQL command' => 'SQL-Päring',
	'Dump' => 'Ekspordi',
	'Logout' => 'Logi välja',
	'database' => 'andmebaas',
	'Use' => 'Kasuta',
	'No tables.' => 'Tabeleid ei leitud.',
	'select' => 'kuva',
	'Create new table' => 'Loo uus tabel',
	'Item has been deleted.' => 'Kustutamine õnnestus.',
	'Item has been updated.' => 'Uuendamine õnnestus.',
	'Item%s has been inserted.' => 'Kirje%s on edukalt lisatud.',
	'Edit' => 'Muuda',
	'Insert' => 'Sisesta',
	'Save and insert next' => 'Salvesta ja lisa järgmine',
	'Delete' => 'Kustuta',
	'Database' => 'Andmebaas',
	'Routines' => 'Protseduurid',
	'Indexes have been altered.' => 'Indeksite andmed on edukalt uuendatud.',
	'Indexes' => 'Indeksid',
	'Alter indexes' => 'Muuda indekseid',
	'Add next' => 'Lisa järgmine',
	'Language' => 'Keel',
	'Select' => 'Kuva',
	'New item' => 'Lisa kirje',
	'Search' => 'Otsi',
	'Sort' => 'Sorteeri',
	'descending' => 'kahanevalt',
	'Limit' => 'Piira',
	'No rows.' => 'Sissekanded puuduvad.',
	'Action' => 'Tegevus',
	'edit' => 'muuda',
	'Page' => 'Lehekülg',
	'Query executed OK, %d row(s) affected.' => 'Päring õnnestus, mõjutatatud ridu: %d.',
	'Error in query' => 'Päringus esines viga',
	'Execute' => 'Käivita',
	'Table' => 'Tabel',
	'Foreign keys' => 'Võõrvõtmed (foreign key)',
	'Triggers' => 'Päästikud (trigger)',
	'View' => 'Vaata',
	'Unable to select the table' => 'Tabeli valimine ebaõnnestus',
	'Invalid CSRF token. Send the form again.' => 'Sobimatu CSRF, palun postitage vorm uuesti.',
	'Comment' => 'Kommentaar',
	'Default values' => 'Vaikimisi väärtused',
	'%d byte(s)' => array('%d bait', '%d baiti'),
	'No commands to execute.' => 'Käsk puudub.',
	'Unable to upload a file.' => 'Faili üleslaadimine pole võimalik.',
	'File upload' => 'Faili üleslaadimine',
	'File uploads are disabled.' => 'Failide üleslaadimine on keelatud.',
	'Routine has been called, %d row(s) affected.' => 'Protseduur täideti edukalt, mõjutatud ridu: %d.',
	'Call' => 'Käivita',
	'No extension' => 'Ei leitud laiendust',
	'None of the supported PHP extensions (%s) are available.' => 'Serveris pole ühtegi toetatud PHP laiendustest (%s).',
	'Session support must be enabled.' => 'Sessioonid peavad olema lubatud.',
	'Session expired, please login again.' => 'Sessioon on aegunud, palun logige uuesti sisse.',
	'Text length' => 'Teksti pikkus',
	'Foreign key has been dropped.' => 'Võõrvõti on edukalt kustutatud.',
	'Foreign key has been altered.' => 'Võõrvõtme andmed on edukalt muudetud.',
	'Foreign key has been created.' => 'Võõrvõri on edukalt loodud.',
	'Foreign key' => 'Võõrvõti',
	'Target table' => 'Siht-tabel',
	'Change' => 'Muuda',
	'Source' => 'Allikas',
	'Target' => 'Sihtkoht',
	'Add column' => 'Lisa veerg',
	'Alter' => 'Muuda',
	'Add foreign key' => 'Lisa võõrvõti',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Indeksi tüüp',
	'Column (length)' => 'Veerg (pikkus)',
	'View has been dropped.' => 'Vaade (VIEW) on edukalt kustutatud.',
	'View has been altered.' => 'Vaade (VIEW) on edukalt muudetud.',
	'View has been created.' => 'Vaade (VIEW) on edukalt loodud.',
	'Alter view' => 'Muuda vaadet (VIEW)',
	'Create view' => 'Loo uus vaade (VIEW)',
	'Name' => 'Nimi',
	'Process list' => 'Protsesside nimekiri',
	'%d process(es) have been killed.' => array('Protsess on edukalt peatatud (%d).', 'Valitud protsessid (%d) on edukalt peatatud.'),
	'Kill' => 'Peata',
	'Parameter name' => 'Parameetri nimi',
	'Database schema' => 'Andmebaasi skeem',
	'Create procedure' => 'Loo uus protseduur',
	'Create function' => 'Loo uus funktsioon',
	'Routine has been dropped.' => 'Protseduur on edukalt kustutatud.',
	'Routine has been altered.' => 'Protseduuri andmed on edukalt muudetud.',
	'Routine has been created.' => 'Protseduur on edukalt loodud.',
	'Alter function' => 'Muuda funktsiooni',
	'Alter procedure' => 'Muuda protseduuri',
	'Return type' => 'Tagastustüüp',
	'Add trigger' => 'Lisa päästik (TRIGGER)',
	'Trigger has been dropped.' => 'Päästik on edukalt kustutatud.',
	'Trigger has been altered.' => 'Päästiku andmed on edukalt uuendatud.',
	'Trigger has been created.' => 'Uus päästik on edukalt loodud.',
	'Alter trigger' => 'Muuda päästiku andmeid',
	'Create trigger' => 'Loo uus päästik (TRIGGER)',
	'Time' => 'Aeg',
	'Event' => 'Sündmus',
	'%d row(s)' => '%d rida',
	'Remove' => 'Eemalda',
	'Are you sure?' => 'Kas oled kindel?',
	'Privileges' => 'Õigused',
	'Create user' => 'Loo uus kasutaja',
	'User has been dropped.' => 'Kasutaja on edukalt kustutatud.',
	'User has been altered.' => 'Kasutaja andmed on edukalt muudetud.',
	'User has been created.' => 'Kasutaja on edukalt lisatud.',
	'Hashed' => 'Häshitud (Hashed)',
	'Column' => 'Veerg',
	'Routine' => 'Protseduur',
	'Grant' => 'Anna',
	'Revoke' => 'Eemalda',
	'%s version: %s through PHP extension %s' => '%s versioon: %s, kasutatud PHP moodul: %s',
	'Logged as: %s' => 'Sisse logitud: %s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST-andmete maht on liialt suur. Palun vähendage andmeid või suurendage %s php-seadet.',
	'Move up' => 'Liiguta ülespoole',
	'Move down' => 'Liiguta allapoole',
	'Export' => 'Ekspordi',
	'Tables' => 'Tabelid',
	'Data' => 'Andmed',
	'Output' => 'Väljund',
	'open' => 'näita brauseris',
	'save' => 'salvesta failina',
	'Format' => 'Formaat',
	'Functions' => 'Funktsioonid',
	'Aggregation' => 'Liitmine',
	'Event has been dropped.' => 'Sündmus on edukalt kustutatud.',
	'Event has been altered.' => 'Sündmuse andmed on edukalt uuendatud.',
	'Event has been created.' => 'Sündmus on edukalt loodud.',
	'Alter event' => 'Muuda sündmuse andmeid',
	'Create event' => 'Loo uus sündmus (EVENT)',
	'Start' => 'Alusta',
	'End' => 'Lõpeta',
	'Every' => 'Iga',
	'Status' => 'Staatus',
	'On completion preserve' => 'Lõpetamisel jäta sündmus alles',
	'Events' => 'Sündmused (EVENTS)',
	'Schedule' => 'Ajakava',
	'At given time' => 'Antud ajahetkel',
	'Save and continue edit' => 'Salvesta ja jätka muutmist',
	'original' => 'originaal',
	'Tables have been truncated.' => 'Validud tabelid on edukalt tühjendatud.',
	'Tables have been moved.' => 'Valitud tabelid on edukalt liigutatud.',
	'Tables have been dropped.' => 'Valitud tabelid on edukalt kustutatud.',
	'Tables and views' => 'Tabelid ja vaated',
	'Engine' => 'Implementatsioon',
	'Collation' => 'Tähetabel',
	'Data Length' => 'Andmete pikkus',
	'Index Length' => 'Indeksi pikkus',
	'Data Free' => 'Vaba ruumi',
	'Rows' => 'Ridu',
	',' => ',',
	'Analyze' => 'Analüüsi',
	'Optimize' => 'Optimeeri',
	'Check' => 'Kontrolli',
	'Repair' => 'Paranda',
	'Truncate' => 'Tühjenda',
	'Move to other database' => 'Liiguta teise andmebaasi',
	'Move' => 'Liiguta',
	'%d item(s) have been affected.' => 'Mõjutatud kirjeid: %d.',
	'whole result' => 'Täielikud tulemused',
	'Clone' => 'Kloon',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Maksimaalne väljade arv ületatud. Palun suurendage %s.',
	'Partition by' => 'Partitsiooni',
	'Partitions' => 'Partitsioonid',
	'Partition name' => 'Partitsiooni nimi',
	'Values' => 'Väärtused',
	'%d row(s) have been imported.' => 'Imporditi %d rida.',
	'anywhere' => 'vahet pole',
	'Import' => 'Impordi',
	'Stop on error' => 'Peatuda vea esinemisel',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$6.$4.$1',
	'[yyyy]-mm-dd' => 'd.m.[yyyy]',
	'History' => 'Ajalugu',
	'Variables' => 'Muutujad',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Lähte- ja sihtveerud peavad eksisteerima ja omama sama andmetüüpi, sihtveergudel peab olema määratud indeks ning viidatud andmed peavad eksisteerima.',
	'Relations' => 'Seosed',
	'Run file' => 'Käivita fail',
	'Clear' => 'Puhasta',
	'Maximum allowed file size is %sB.' => 'Maksimaalne failisuurus %sB.',
	'Numbers' => 'Numbrilised',
	'Date and time' => 'Kuupäev ja kellaaeg',
	'Strings' => 'Tekstid',
	'Binary' => 'Binaar',
	'Lists' => 'Listid',
	'Editor' => 'Redaktor',
	'E-mail' => 'E-post',
	'From' => 'Kellelt',
	'Subject' => 'Pealkiri',
	'Send' => 'Saada',
	'%d e-mail(s) have been sent.' => 'Saadetud kirju: %d.',
	'Webserver file %s' => 'Fail serveris: %s',
	'File does not exist.' => 'Faili ei leitud.',
	'%d in total' => 'Kokku: %d',
	'Permanent login' => 'Jäta mind meelde',
	'Databases have been dropped.' => 'Andmebaasid on edukalt kustutatud.',
	'Search data in tables' => 'Otsi kogu andmebaasist',
	'schema' => 'struktuur',
	'Schema' => 'Struktuur',
	'Alter schema' => 'Muuda struktuuri',
	'Create schema' => 'Loo struktuur',
	'Schema has been dropped.' => 'Struktuur on edukalt kustutatud.',
	'Schema has been created.' => 'Struktuur on edukalt loodud.',
	'Schema has been altered.' => 'Struktuur on edukalt muudetud.',
	'Sequences' => 'Jadad (sequences)',
	'Create sequence' => 'Loo jada',
	'Alter sequence' => 'Muuda jada',
	'Sequence has been dropped.' => 'Jada on edukalt kustutatud.',
	'Sequence has been created.' => 'Jada on edukalt loodud.',
	'Sequence has been altered.' => 'Jada on edukalt muudetud.',
	'User types' => 'Kasutajatüübid',
	'Create type' => 'Loo tüüp',
	'Alter type' => 'Muuda tüüpi',
	'Type has been dropped.' => 'Tüüp on edukalt kustutatud.',
	'Type has been created.' => 'Tüüp on edukalt loodud.',
	'Ctrl+click on a value to modify it.' => 'Väärtuse muutmiseks Ctrl+kliki sellel.',
	'Use edit link to modify this value.' => 'Väärtuse muutmiseks kasuta muutmislinki.',
	'last' => 'viimane',
	'From server' => 'Serverist',
	'System' => 'Andmebaasimootor',
	'Select data' => 'Vaata andmeid',
	'Show structure' => 'Näita struktuuri',
	'empty' => 'tühi',
	'Network' => 'Võrk (network)',
	'Geometry' => 'Geomeetria',
	'File exists.' => 'Fail juba eksisteerib.',
	'Attachments' => 'Manused',
	'%d query(s) executed OK.' => array('%d päring edukalt käivitatud.', '%d päringut edukalt käivitatud.'),
	'Show only errors' => 'Kuva vaid veateateid',
	'Refresh' => 'Uuenda',
	'Invalid schema.' => 'Sobimatu skeema.',
	'Please use one of the extensions %s.' => 'Palun kasuta üht laiendustest %s.',
	'now' => 'nüüd',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tabelid on edukalt kopeeritud.',
	'Copy' => 'Kopeeri',
	'Permanent link' => 'Püsilink',
	'Edit all' => 'Muuda kõiki',
	'HH:MM:SS' => 'HH:MM:SS',
);
